package com.ruoyi.change.service;

import java.util.List;
import com.ruoyi.change.domain.TbAssetOrderDetail;

/**
 * 资产单据明细Service接口
 * 
 * @author 原动力
 * @date 2023-05-15
 */
public interface ITbAssetOrderDetailService 
{
    /**
     * 查询资产单据明细
     * 
     * @param id 资产单据明细主键
     * @return 资产单据明细
     */
    public TbAssetOrderDetail selectTbAssetOrderDetailById(Long id);

    /**
     * 查询资产单据明细列表
     * 
     * @param tbAssetOrderDetail 资产单据明细
     * @return 资产单据明细集合
     */
    public List<TbAssetOrderDetail> selectTbAssetOrderDetailList(TbAssetOrderDetail tbAssetOrderDetail);

    /**
     * 新增资产单据明细
     * 
     * @param tbAssetOrderDetail 资产单据明细
     * @return 结果
     */
    public int insertTbAssetOrderDetail(TbAssetOrderDetail tbAssetOrderDetail);

    /**
     * 修改资产单据明细
     * 
     * @param tbAssetOrderDetail 资产单据明细
     * @return 结果
     */
    public int updateTbAssetOrderDetail(TbAssetOrderDetail tbAssetOrderDetail);

    /**
     * 批量删除资产单据明细
     * 
     * @param ids 需要删除的资产单据明细主键集合
     * @return 结果
     */
    public int deleteTbAssetOrderDetailByIds(Long[] ids);

    /**
     * 删除资产单据明细信息
     * 
     * @param id 资产单据明细主键
     * @return 结果
     */
    public int deleteTbAssetOrderDetailById(Long id);
}
