package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetOrderDetail;
import com.ruoyi.change.service.ITbAssetOrderDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产单据明细Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/orderDetail")
public class TbAssetOrderDetailController extends BaseController
{
    @Autowired
    private ITbAssetOrderDetailService tbAssetOrderDetailService;

    /**
     * 查询资产单据明细列表
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetOrderDetail tbAssetOrderDetail)
    {
        startPage();
        List<TbAssetOrderDetail> list = tbAssetOrderDetailService.selectTbAssetOrderDetailList(tbAssetOrderDetail);
        return getDataTable(list);
    }

    /**
     * 导出资产单据明细列表
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:export')")
    @Log(title = "资产单据明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetOrderDetail tbAssetOrderDetail)
    {
        List<TbAssetOrderDetail> list = tbAssetOrderDetailService.selectTbAssetOrderDetailList(tbAssetOrderDetail);
        ExcelUtil<TbAssetOrderDetail> util = new ExcelUtil<TbAssetOrderDetail>(TbAssetOrderDetail.class);
        util.exportExcel(response, list, "资产单据明细数据");
    }

    /**
     * 获取资产单据明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetOrderDetailService.selectTbAssetOrderDetailById(id));
    }

    /**
     * 新增资产单据明细
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:add')")
    @Log(title = "资产单据明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetOrderDetail tbAssetOrderDetail)
    {
        return toAjax(tbAssetOrderDetailService.insertTbAssetOrderDetail(tbAssetOrderDetail));
    }

    /**
     * 修改资产单据明细
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:edit')")
    @Log(title = "资产单据明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetOrderDetail tbAssetOrderDetail)
    {
        return toAjax(tbAssetOrderDetailService.updateTbAssetOrderDetail(tbAssetOrderDetail));
    }

    /**
     * 删除资产单据明细
     */
    @PreAuthorize("@ss.hasPermi('change:orderDetail:remove')")
    @Log(title = "资产单据明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetOrderDetailService.deleteTbAssetOrderDetailByIds(ids));
    }
}
